capture log close sublog
log using "$prdir/log/cw/fema_cty_to_cz.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Collapse the FEMA application counts and population from counties 
* into CZs. For the 48 contiguous states, only
* Author: Justin Wiltshire
	
* Updated: September 25, 2019
*-------------------------------------------------------------------------------

tempfile core

* Load the FEMA applications and population counts by county data 
use "$prdir/cw/geo/dta/cty_cz/cln/FEMA_cty.dta", clear

* Rename county FIPS
rename county cty_fips
rename cty_pop cty_pop2

* Drop Alaska and Hawaii
drop if inlist(floor(cty_fips/1000), 2, 15)

* Map counties backward as needed in order to map into 1990 CZs
cty_remap

* Collapse the applications and population counts by unique county
collapse (sum) fema_apps cty_pop, by(cty_fips)

sort cty_fips fema_apps cty_pop

save "`core'"

* Merge with county population data for whole country to get complete county data
* Map poppulation data backward as needed in order to map into 1990 CZs
use "$prdir/cw/geo/dta/cty_pop/cty_pop.dta", clear
rename county cty_fips
cty_remap

* Collapse into unique updated counties
collapse (sum) cty_pop, by(cty_fips)
sort cty_fips cty_pop

* Drop Alaska and Hawaii
drop if inlist(floor(cty_fips/1000), 2, 15)

* Merge in the FEMA data
merge 1:1 cty_fips using "`core'", nogenerate

* Populate the missing cells
assert cty_pop == cty_pop2 if !mi(cty_pop2)
drop cty_pop2
recode fema_apps (.=0)

* Merge in the (updated) David Dorn county to CZ crosswalk. 3 unmatched CZs no concern
merge 1:1 cty_fips using "$prdir/cw/geo/dta/cty_cz/cln/cw_cty_czone.dta", keep(3) nogenerate noreport

* Collapse into CZs
collapse (sum) fema_apps cz_pop=cty_pop, by(czone)

* Create per-capita applications
qui gen pc_fema_apps = fema_apps/cz_pop

* Clean up
rename czone cz
replace pc_fema_apps = round(pc_fema_apps,0.00001)
replace fema_apps = round(fema_apps)
sort cz fema_apps pc_fema_apps cz_pop
order cz fema_apps pc_fema_apps cz_pop

* Save the data
compress
save "$prdir/cw/geo/dta/cty_cz/cln/fema_cz.dta", replace

* Close the log file
log close sublog
