capture log close sublog
log using "$prdir/cw/pce/log/pce_builder.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Prepares the Personal Consumption Expenditures time series.
* Author: Brendan Price (modified by Justin Wiltshire)
*
* Updated: 20190307
*-------------------------------------------------------------------------------

*-------------------------------------------------------------------------------
* Load raw PCE data from FRED
*-------------------------------------------------------------------------------

* Load raw PCE data
freduse PCEPI PCEPILFE CPIAUCSL CPILFESL, clear
gen year = yofd(daten)
gen month = month(daten)
gen tm = mofd(daten)
rename PCEPI pce
rename PCEPILFE pcelfe
rename CPIAUCSL cpi
rename CPILFESL cpilfe

* Store indices at monthly frequency
tempfile fred_mthly
save "`fred_mthly'"

*-------------------------------------------------------------------------------
* Save annual price indices
*-------------------------------------------------------------------------------

* Normalize prices to 2017 dollars
collapse (mean) pce pcelfe cpi cpilfe, by(year)
egen pce17 = total(pce * (year == 2017))
replace pce = pce / pce17

* Save the PCE series
keep year pce
compress
sort year
order year pce
label var year "Year"
label var pce "Personal Consumption Expenditures chain-type price index (2017 = 1)"
save "$prdir/cw/pce/dta/cln/pce_ann.dta", replace

*-------------------------------------------------------------------------------
* Save monthly price indices
*-------------------------------------------------------------------------------

* Reload the PCE data
use "`fred_mthly'", clear

* Normalize prices to January 2017 dollars
egen pce17 = total(pce * (year == 2017 & month == 1))
replace pce = pce / pce17

* Save the PCE series
keep tm year month pce
compress
format %tm tm
sort tm
order tm year month pce
label var tm "Year/month"
label var year "Year"
label var month "Month"
label var pce "Personal Consumption Expenditures chain-type price index (Jan. 2017 = 1)"
save "$prdir/cw/pce/dta/cln/pce_mth.dta", replace

* Close the log file
log close sublog
