*-------------------------------------------------------------------------------
* Description: This do file performs the analyses on the zillow data
* Author: Derek Rury (6/24/20)
* Modified by: Justin Wiltshire 
*
* Updated: February 25, 2021
*-------------------------------------------------------------------------------

*********
*Preamble
*********

clear
set more off

local data "$prdir/dta"
**************
*Begin do file
**************

use `data'/cln/zillow/zillow_clean

replace value = ln(value)


gen norm_value = .

replace norm_value = 1 - 12.31721143476 + value if orlando == 1
replace norm_value = 1 + value - 12.05198863015 if regionid == 394763
replace norm_value = 1 + value - 12.40434136765 if regionid == 394775
replace norm_value = 1 + value - 12.33762708527 if regionid == 395194
replace norm_value = 1 + value - 12.43754541242 if regionid == 395048
replace norm_value = 1 + value - 12.38119333822 if regionid == 394399
replace norm_value = 1 + value - 11.42759630862 if regionid == 394333
replace norm_value = 1 + value - 12.60918498805 if regionid == 395006
replace norm_value = 1 + value - 12.53798808714 if regionid == 394444

label var norm_value "Log Zillow Price Index"

********************
*Diff in Diff models
********************

eststo clear
tsset regionid month
eststo: xtreg value orlando_post i.month [aw=wt] if in_sample == 1 & inrange(month, 648, 704), fe vce(robust)

eststo: reg value orlando_post orlando i.month if (orlando == 1 | synth_group == 1) & inrange(month, 648, 704), vce(robust)

esttab using "$prdir/out/analysis/zillow/zillow_dd.tex", replace keep(orlando_post) label se

****************
*Plotting Prices
****************
twoway line value month if orlando == 1 & month >= 648 ///
	|| line value month if regionid == 394763 & month >= 648 ///
	|| line value month if regionid == 394775 & month >= 648 ///
	|| line value month if regionid == 395194 & month >= 648 ///
	|| line value month if regionid == 395048 & month >= 648 ///
	|| line value month if regionid == 394399 & month >= 648 ///
	|| line value month if regionid == 395006 & month >= 648 ///
	|| line value month if regionid == 394444 & month >= 648 ///
	|| line value month if regionid == 394333 & month >= 648, xline(692) ///
	scheme(s2color)

twoway line value month if orlando == 1 & month >= 648 ///
	|| line value month if synth_group == 1 & month >= 648, xline(692)

#delimit ;
	twoway (line norm_value month if orlando == 1 & month >= 648, lcolor(black) lp(solid) lwidth(thick))
		|| (line norm_value month if regionid == 394763 & month >= 648, lcolor(gs8) lp(dash))
		|| (line norm_value month if regionid == 394775 & month >= 648, lcolor(gs8) lp(dot))
		|| (line norm_value month if regionid == 395194 & month >= 648, lcolor(gs8) lp(dash_dot))
		|| (line norm_value month if regionid == 395048 & month >= 648, lcolor(gs8) lp(shortdash))
		|| (line norm_value month if regionid == 394399 & month >= 648, lcolor(gs8) lp(shortdash_dot))
		|| (line norm_value month if regionid == 395006 & month >= 648, lcolor(gs8) lp(longdash))
		|| (line norm_value month if regionid == 394444 & month >= 648, lcolor(gs8) lp(longdash_dot))
		|| (line norm_value month if regionid == 394333 & month >= 648, lcolor(gs8) lp("-....")),
		xline(692, lwidth(1.5) lcolor(gs12))
		xline(691.5 692.5, lp(dot) lcolor(gs8))
		ytitle("")
		plotregion(margin(zero))
		yscale(range(0.4 1.4)) ylabel(0.4 (0.2) 1.4)
		tlabel(2014m1(12)2020m1, angle(45)) ttick(#7)
		graphregion(fcolor(white))
		legend(label(1 "Orlando") label(2 "Lake Charles, LA") label(3 "Las Vegas, NV") label(4 "Virginia Beach, VA") label(5 "Salem, OR") label(6 "Boise, ID") label(7 "Provo, UT") label(8 "Carson City, NV") label(9 "Anniston, AL"));
	#delimit cr
	
nicepdf "$prdir/out/analysis/zillow/norm_zillow_price_index.pdf", replace

twoway line norm_value month if orlando == 1 & month >= 648 ///
	|| line norm_value month if synth_group == 1 & month >= 648, xline(692)

