capture log close sublog
log using "$prdir/log/check/orl_emp_shr_by_ind.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Plot the Orlando employment share by industry
* Author: Justin Wiltshire
	
* Updated: February 13, 2020
*-------------------------------------------------------------------------------

* Loop over Q2 2017 & 2018
forval t = 688(12)700 {

	* Load the Hispanic QWI data
	qui use "$prdir/dta/cln/qwi/qwi_naics_cz_hisp.dta", clear

	* Restrict the data to the separate industries in Q2 in each year in Orlando
	qui keep if tm == `t' & cz == 7400
	qui keep cz emp naics

	* Create the employment proportion by industry over this period
	qui gen tot_emp = emp if naics == 10
	qui replace tot_emp = tot_emp[1]
	qui drop if naics == 10
	qui gen prop_emp_hisp = emp/tot_emp
	qui label var prop_emp "Employment share"

	* Save tempfile
	if `t' == 688 {
		tempfile core
		qui save "`core'", replace
	}
	if `t' == 700 {
		tempfile core2
		qui save "`core2'", replace
	}
}

* Load the QCEW data for Q2 2017
qui use "$prdir/dta/cln/qcew/qcew_naics_cz.dta", clear

* Restrict the data to the separate industries in Q2 2017 in Orlando
qui keep if inrange(tm, 687, 689) & cz == 7400
qui collapse (mean) emp, by(cz naics)

* Create the employment proportion by industry over this period
qui gen tot_emp = emp if naics == 10
qui replace tot_emp = tot_emp[1]
qui drop if naics == 10
qui gen prop_emp = emp/tot_emp
qui label var prop_emp "Employment share"

* Graph it
#delimit ;
	qui graph 
		hbar prop_emp, 
		over(naics)
		bar(1, color(gs0))
		title("Industrial employment shares")
		subtitle("All workers in Orlando, Q2 2017")
		ytitle("")
		b1title("Employment share")
		graphregion(color(white));
	#delimit cr
qui graph export "$prdir/out/check/emp_shr/orl_emp_by_ind_all_2017q2.pdf", replace

merge 1:1 naics using "`core'", nogen norep keep(3)

* Graph it
#delimit ;
	qui graph 
		hbar prop_emp prop_emp_hisp, 
		over(naics)
		bar(1, color(gs0)) bar(2, color(gs10))
		title("Industrial employment shares")
		subtitle("Orlando, Q2 2017 (Selected industries)")
		ytitle("")
		b1title("Employment share")
		legend(rows(2) label(1 "Among all workers") label(2 "Among Hispanic workers"))
		graphregion(color(white));
	#delimit cr
qui graph export "$prdir/out/check/emp_shr/orl_emp_by_ind_all_vs_hisp_2017q2.pdf", replace

* Load the QCEW data for Q2 2018
qui use "$prdir/dta/cln/qcew/qcew_naics_cz.dta", clear

* Restrict the data to the separate industries in Q2 2017 in Orlando
qui keep if inrange(tm, 699, 701) & cz == 7400
qui collapse (mean) emp, by(cz naics)

* Create the employment proportion by industry over this period
qui gen tot_emp = emp if naics == 10
qui replace tot_emp = tot_emp[1]
qui drop if naics == 10
qui gen prop_emp = emp/tot_emp
qui label var prop_emp "Employment share"

* Graph it
merge 1:1 naics using "`core2'", nogen norep keep(3)

* Graph it
#delimit ;
	qui graph 
		hbar prop_emp prop_emp_hisp, 
		over(naics)
		bar(1, color(gs0)) bar(2, color(gs10))
		title("Industrial employment shares")
		subtitle("Orlando, Q2 2018 (Selected industries)")
		ytitle("")
		b1title("Employment share")
		legend(rows(2) label(1 "Among all workers") label(2 "Among Hispanic workers"))
		graphregion(color(white));
	#delimit cr
qui graph export "$prdir/out/check/emp_shr/orl_emp_by_ind_all_vs_hisp_2018q2.pdf", replace

* Close the log file
log close sublog
