capture log close sublog
log using "$prdir/log/check/all_donor_pool_maps.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Create maps of the entire donor pool by industry
* Author: Justin Wiltshire
	
* Updated: July 25, 2020
*-------------------------------------------------------------------------------

* Loop over the industries
local graphlist ""
foreach ind in 10 23 44 72 {

	* Load and clean the data
	use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/resid_ln_emp/deseasonalize_n`ind'.dta", clear
	rename _Co_Number cz
	drop if mi(cz)
	qui gen wt = _W_Weight*100
	format wt %2.1g
	qui replace wt = 1

	* Create the cut values and the macros for the donor pool
	if `ind' == 10 {
		local tit = "Panel A: Aggregate"
	}
	if `ind' == 23 {
		local tit = "Panel B: Construction"
	}
	if `ind' == 44 {
		local tit = "Panel C: Retail"
	}
	if `ind' == 72 {
		local tit = "Panel D: Hospitality"
	}
	
	* Make the maps
	maptile wt, geo(cz1990) conus fcolor(black) ndfcolor(white) ///
	twopt(legend(pos(7) label(1 "Not in donor pool") label(2 "In donor pool")))
		
	* Copy graph
	graph copy gr`ind', replace
	graph combine gr`ind', imargin(vsmall) title("`tit'")
	graph copy gr`ind', replace
	local graphlist "`graphlist' gr`ind'"
}
	
* Place on one graph
graph combine `graphlist', imargin(vsmall) rows(2)
graph export "$prdir/out/check/sc_weight_maps/all_donor_pool_combined.pdf", replace

* Close the log file
log close sublog
