capture log close sublog
log using "$prdir/log/check/donor_maps.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Create maps of the donor CZs by weight
* Author: Justin Wiltshire
	
* Updated: July 29, 2020
*-------------------------------------------------------------------------------

* Loop over the industries
foreach y in resid_ln_emp resid_ln_avg_wkly_wage {
	local graphlist ""
	foreach ind in 10 23 44 72 {

		use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`y'/deseasonalize_n`ind'.dta", clear
		rename _Co_Number cz
		drop if mi(cz)
		qui gen wt = _W_Weight*100
		format wt %2.1g

		* Create the cut values and the macros for the donor pool
		if "`y'" == "resid_ln_emp" {
			if `ind' == 10 {
				local grtit "Panel A: Aggregate Employment"
				local cuts "0.1 10 25"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 20%") label(5 "26.9%")"'
			}
			else if `ind' == 23 {
				local grtit "Panel B: Construction Employment"
				local cuts "0.1 10 24"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 21%") label(5 "24.3%")"'
			}
			else if `ind' == 44 {
				local grtit "Retail"
				local cuts "0.1 10 15 20 25"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 15%") label(5 "20.8%") label(6 "26.6%")"'
			}
			else if `ind' == 72 {
				local grtit "Hospitality"
				local cuts "0.1 10 15 20 25"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 15%") label(5 "16.4%") label(6 "25.6%")"'
			}
		}
		if "`y'" == "resid_ln_avg_wkly_wage" {
			if `ind' == 10 {
				local grtit "Panel C: Aggregate Earnings per Worker"
				local cuts "0.1 10 24"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 20%") label(5 "24.3%")"'
			}
			else if `ind' == 23 {
				local grtit "Panel D: Construction Earnings per Worker"
				local cuts "0.1 10 33"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 20%") label(5 "33.6%")"'
			}
			else if `ind' == 44 {
				local grtit "Retail"
				local cuts "0.1 5 10 15 25"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 5%") label(4 "5 - 10%") label(5 "18.4") label(6 "46.4%")"'
			}
			else if `ind' == 72 {
				local grtit "Hospitality"
				local cuts "0.1 10 15 16 17 18"
				local label = `"label(1 "Not in donor pool") label(2 "0%") label(3 "< 10%") label(4 "10 - 15%") label(5 "16.2%") label(6 "17.4%") label(7 "18.2%")"'
			}
		}

		maptile wt, geo(cz1990) conus ndfcolor(white) ///
		cutvalues (`cuts') ///
		twopt(legend(pos(7) `label')) ///
		savegraph("$prdir/out/check/sc_weight_maps/yr_hole_`y'_`ind'.pdf") replace
		 
		maptile wt, geo(cz1990) conus fcolor(Greys) ndfcolor(white) ///
		cutvalues (`cuts') ///
		twopt(legend(pos(7) `label')) ///
		savegraph("$prdir/out/check/sc_weight_maps/yr_hole_`y'_`ind'_greys.pdf") replace
		
		* Copy certain graphs
		if inlist(`ind', 10, 23) {
			graph copy gr`y'`ind', replace
			graph combine gr`y'`ind', imargin(vsmall) title("`grtit'")
			graph copy gr`y'`ind', replace
			local graphlist "`graphlist' gr`y'`ind'"
		}
	}
	
	* Place on one graph and copy
	graph combine `graphlist', imargin(vsmall)
	graph copy `y', replace
	di "Copying graph `y'"
}

* Place on one graph
graph combine resid_ln_emp resid_ln_avg_wkly_wage, imargin(vsmall) rows(2)
graph export "$prdir/out/check/sc_weight_maps/combined_greys.pdf", replace

* Close the log file
log close sublog
