capture log close sublog
log using "$prdir/log/check/donor_tables.txt", name(sublog) text replace

*-------------------------------------------------------------------------------
* Description: Create tables of the donor CZs by weight
* Author: Justin Wiltshire
	
* Updated: June 20, 2020
*-------------------------------------------------------------------------------

* Loop over the industries
foreach y in resid_ln_emp resid_ln_avg_wkly_wage {
	local graphlist ""
	foreach ind in 10 23 44 72 {
	
		* Load and clean the synthetic control results
		use "$prdir/dta/analysis/qcew/sc_results_dta/cz_7400/`y'/deseasonalize_n`ind'.dta", clear
		rename _Co_Number cz
		drop if mi(cz)
		qui gen wt = _W_Weight*100
		qui keep if wt > 0
		qui keep cz wt
		qui gsort -wt
		qui mkmat cz wt, mat(vals`y'`ind')
		
		* Make the tables
		qui capture mkdir "$prdir/out/check/sc_weight_tables"
		frmttable using "$prdir/out/check/sc_weight_tables/`y'_ind`ind'", replace tex statmat(vals`y'`ind') sdec(1) ///
		title("`y'; Ind: `ind'") ///
		ctitles("Commuting Zone","Weight (\%)")
	}
}

* Close the log file
log close sublog
